@@ -15,6 +15,7 @@ from .ascii85test import Ascii85test
 from .asuphoenix import Asuphoenix
 from .ax25frames import Ax25frames
 from .ax25monitor import Ax25monitor
+from .bdsat import Bdsat
 from .bisonsat import Bisonsat
 from .bobcat1 import Bobcat1
 from .bugsat1 import Bugsat1
@@ -36,7 +37,11 @@ from .entrysat import Entrysat
 from .equisat import Equisat
 from .eshail2 import Eshail2
 from .fox import Fox
+from .gaspacs import Gaspacs
 from .grbalpha import Grbalpha
+from .grizu263a import Grizu263a
+from .gt1 import Gt1
+from .inspiresat1 import Inspiresat1
 from .irazu import Irazu
 from .irvine import Irvine
 from .iss import Iss
@@ -52,6 +57,7 @@ from .mysat import Mysat
 from .netsat import Netsat
 from .neutron1 import Neutron1
 from .opssat1 import Opssat1
+from .oresat0 import Oresat0
 from .origamisat1 import Origamisat1
 from .painani import Painani
 from .polyitan1 import Polyitan1
@@ -62,10 +68,12 @@ from .qubik import Qubik
 from .quetzal1 import Quetzal1
 from .ramsat import Ramsat
 from .salsat import Salsat
+from .sanosat1 import Sanosat1
 from .siriussat import Siriussat
 from .skcube import Skcube
 from .spoc import Spoc
 from .strand import Strand
+from .targit import Targit
 from .us6 import Us6
 from .uwe4 import Uwe4
 from .vzlusat2 import Vzlusat2
@@ -80,6 +88,7 @@ __all__ = [
     'Asuphoenix',
     'Ax25frames',
     'Ax25monitor',
+    'Bdsat',
     'Bisonsat',
     'Bobcat1',
     'Bugsat1',
@@ -101,7 +110,11 @@ __all__ = [
     'Eshail2',
     'Equisat',
     'Fox',
+    'Gaspacs',
     'Grbalpha',
+    'Grizu263a',
+    'Gt1',
+    'Inspiresat1',
     'Irazu',
     'Irvine',
     'Iss',
@@ -117,6 +130,7 @@ __all__ = [
     'Netsat',
     'Neutron1',
     'Opssat1',
+    'Oresat0',
     'Origamisat1',
     'Painani',
     'Polyitan1',
@@ -127,10 +141,12 @@ __all__ = [
     'Quetzal1',
     'Ramsat',
     'Salsat',
+    'Sanosat1',
     'Siriussat',
     'Skcube',
     'Spoc',
     'Strand',
+    'Targit',
     'Us6',
     'Uwe4',
     'Vzlusat2',
