@@ -112,7 +112,24 @@ class Bobcat1(KaitaiStruct):
     :field a3200_hktable_17_2_timestamp: frame.extra_frame.a3200_hktable_17_2.timestamp
     :field a3200_hktable_17_2_source: frame.extra_frame.a3200_hktable_17_2.source
     :field custom_message: frame.extra_frame.custom_message
+    :field rev: frame.fwdebug_frame.rev
+    :field swload_cnt1: frame.fwdebug_frame.swload_cnt1
+    :field swload_cnt2: frame.fwdebug_frame.swload_cnt2
+    :field ram_image: frame.fwdebug_frame.ram_image
     :field framelength: framelength
+    :field pos_sol_status: frame.xyz_frame.pos_sol_status
+    :field gps_week: frame.xyz_frame.gps_week
+    :field gps_ms: frame.xyz_frame.gps_ms
+    :field pos_x: frame.xyz_frame.pos_x
+    :field pos_y: frame.xyz_frame.pos_y
+    :field pos_z: frame.xyz_frame.pos_z
+    :field vel_x: frame.xyz_frame.vel_x
+    :field vel_y: frame.xyz_frame.vel_y
+    :field vel_z: frame.xyz_frame.vel_z
+    :field vel_latency: frame.xyz_frame.vel_latency
+    :field diff_age: frame.xyz_frame.diff_age
+    :field sol_age: frame.xyz_frame.sol_age
+    :field num_soln_svs: frame.xyz_frame.num_soln_svs
     """
     def __init__(self, _io, _parent=None, _root=None):
         self._io = _io
@@ -122,12 +139,16 @@ class Bobcat1(KaitaiStruct):
 
     def _read(self):
         _on = self._root.framelength
-        if _on == 69:
+        if _on == 150:
+            self.frame = Bobcat1.Bc1ExtraFrame(self._io, self, self._root)
+        elif _on == 98:
+            self.frame = Bobcat1.Bc1XyzFrame(self._io, self, self._root)
+        elif _on == 69:
             self.frame = Bobcat1.Bc1BasicFrame(self._io, self, self._root)
         elif _on == 156:
             self.frame = Bobcat1.Bc1HkFrame(self._io, self, self._root)
-        elif _on == 150:
-            self.frame = Bobcat1.Bc1ExtraFrame(self._io, self, self._root)
+        elif _on == 70:
+            self.frame = Bobcat1.Bc1FwdebugFrame(self._io, self, self._root)
 
     class BeaconElementHeader(KaitaiStruct):
         def __init__(self, _io, _parent=None, _root=None):
@@ -142,6 +163,30 @@ class Bobcat1(KaitaiStruct):
             self.source = self._io.read_u2be()
 
 
+    class XyzFrame(KaitaiStruct):
+        def __init__(self, _io, _parent=None, _root=None):
+            self._io = _io
+            self._parent = _parent
+            self._root = _root if _root else self
+            self._read()
+
+        def _read(self):
+            self.callsigns = Bobcat1.Callsigns(self._io, self, self._root)
+            self.pos_sol_status = self._io.read_u4be()
+            self.gps_week = self._io.read_u2be()
+            self.gps_ms = self._io.read_u4be()
+            self.pos_x = self._io.read_f8be()
+            self.pos_y = self._io.read_f8be()
+            self.pos_z = self._io.read_f8be()
+            self.vel_x = self._io.read_f8be()
+            self.vel_y = self._io.read_f8be()
+            self.vel_z = self._io.read_f8be()
+            self.vel_latency = self._io.read_f4be()
+            self.diff_age = self._io.read_f4be()
+            self.sol_age = self._io.read_f4be()
+            self.num_soln_svs = self._io.read_u1()
+
+
     class Cspheader(KaitaiStruct):
         def __init__(self, _io, _parent=None, _root=None):
             self._io = _io
@@ -153,6 +198,18 @@ class Bobcat1(KaitaiStruct):
             self.data = self._io.read_u4be()
 
 
+    class Bc1XyzFrame(KaitaiStruct):
+        def __init__(self, _io, _parent=None, _root=None):
+            self._io = _io
+            self._parent = _parent
+            self._root = _root if _root else self
+            self._read()
+
+        def _read(self):
+            self.cspheader = Bobcat1.Cspheader(self._io, self, self._root)
+            self.xyz_frame = Bobcat1.XyzFrame(self._io, self, self._root)
+
+
     class Bc1HkFrame(KaitaiStruct):
         def __init__(self, _io, _parent=None, _root=None):
             self._io = _io
@@ -250,6 +307,25 @@ class Bobcat1(KaitaiStruct):
             self.bootcause_ax100 = self._io.read_u4be()
 
 
+    class FwdebugFrame(KaitaiStruct):
+        def __init__(self, _io, _parent=None, _root=None):
+            self._io = _io
+            self._parent = _parent
+            self._root = _root if _root else self
+            self._read()
+
+        def _read(self):
+            self.a3200_hktable17 = Bobcat1.BeaconElementHeader(self._io, self, self._root)
+            self.callsigns = Bobcat1.Callsigns(self._io, self, self._root)
+            self.a3200_hktable0 = Bobcat1.BeaconElementHeader(self._io, self, self._root)
+            self.rev = self._io.read_u1()
+            self.a3200_hktable1 = Bobcat1.BeaconElementHeader(self._io, self, self._root)
+            self.swload_cnt1 = self._io.read_u2be()
+            self.swload_cnt2 = self._io.read_u2be()
+            self.a3200_hktable4 = Bobcat1.BeaconElementHeader(self._io, self, self._root)
+            self.ram_image = self._io.read_u1()
+
+
     class Bc1ExtraFrame(KaitaiStruct):
         def __init__(self, _io, _parent=None, _root=None):
             self._io = _io
@@ -308,6 +384,19 @@ class Bobcat1(KaitaiStruct):
             self.timestamp = self._io.read_u4be()
 
 
+    class Bc1FwdebugFrame(KaitaiStruct):
+        def __init__(self, _io, _parent=None, _root=None):
+            self._io = _io
+            self._parent = _parent
+            self._root = _root if _root else self
+            self._read()
+
+        def _read(self):
+            self.cspheader = Bobcat1.Cspheader(self._io, self, self._root)
+            self.hk_header = Bobcat1.HkHeader(self._io, self, self._root)
+            self.fwdebug_frame = Bobcat1.FwdebugFrame(self._io, self, self._root)
+
+
     class Callsigns(KaitaiStruct):
         def __init__(self, _io, _parent=None, _root=None):
             self._io = _io
