@@ -3,6 +3,7 @@
 from pkg_resources import parse_version
 import kaitaistruct
 from kaitaistruct import KaitaiStruct, KaitaiStream, BytesIO
+import satnogsdecoders.process
 
 
 if parse_version(kaitaistruct.__version__) < parse_version('0.9'):
@@ -20,7 +21,6 @@ class Grbalpha(KaitaiStruct):
     :field repeater_rpt_instance_rpt_ssid_raw_ssid: ax25_frame.ax25_header.repeater.rpt_instance.rpt_ssid_raw.ssid
     :field ctl: ax25_frame.ax25_header.ctl
     :field pid: ax25_frame.payload.pid
-    :field packet_type: ax25_frame.payload.ax25_info.packet_type
     :field pkt_type: ax25_frame.payload.ax25_info.body.pkt_type
     :field uptime_total: ax25_frame.payload.ax25_info.body.uptime_total
     :field uptime_since_last: ax25_frame.payload.ax25_info.body.uptime_since_last
@@ -51,7 +51,46 @@ class Grbalpha(KaitaiStruct):
     :field rs485_transmitted: ax25_frame.payload.ax25_info.body.rs485_transmitted
     :field csp_mcu_received: ax25_frame.payload.ax25_info.body.csp_mcu_received
     :field csp_mcu_transmitted: ax25_frame.payload.ax25_info.body.csp_mcu_transmitted
-    :field string: ax25_frame.payload.ax25_info.body.string
+    :field obc_timestamp: ax25_frame.payload.ax25_info.body.bytes.obc_timestamp
+    :field obc_temp: ax25_frame.payload.ax25_info.body.bytes.obc_temp
+    :field obc_tmp112_xp: ax25_frame.payload.ax25_info.body.bytes.obc_tmp112_xp
+    :field obc_tmp112_yp: ax25_frame.payload.ax25_info.body.bytes.obc_tmp112_yp
+    :field obc_tmp112_xn: ax25_frame.payload.ax25_info.body.bytes.obc_tmp112_xn
+    :field obc_tmp112_yn: ax25_frame.payload.ax25_info.body.bytes.obc_tmp112_yn
+    :field obc_tmp112_zp: ax25_frame.payload.ax25_info.body.bytes.obc_tmp112_zp
+    :field obc_mag_mmc_x: ax25_frame.payload.ax25_info.body.bytes.obc_mag_mmc_x
+    :field obc_mag_mmc_y: ax25_frame.payload.ax25_info.body.bytes.obc_mag_mmc_y
+    :field obc_mag_mmc_z: ax25_frame.payload.ax25_info.body.bytes.obc_mag_mmc_z
+    :field obc_mag_mpu_x: ax25_frame.payload.ax25_info.body.bytes.obc_mag_mpu_x
+    :field obc_mag_mpu_y: ax25_frame.payload.ax25_info.body.bytes.obc_mag_mpu_y
+    :field obc_mag_mpu_z: ax25_frame.payload.ax25_info.body.bytes.obc_mag_mpu_z
+    :field obc_mpu_temp: ax25_frame.payload.ax25_info.body.bytes.obc_mpu_temp
+    :field obc_gyr_mpu_x: ax25_frame.payload.ax25_info.body.bytes.obc_gyr_mpu_x
+    :field obc_gyr_mpu_y: ax25_frame.payload.ax25_info.body.bytes.obc_gyr_mpu_y
+    :field obc_gyr_mpu_z: ax25_frame.payload.ax25_info.body.bytes.obc_gyr_mpu_z
+    :field obc_acc_mpu_x: ax25_frame.payload.ax25_info.body.bytes.obc_acc_mpu_x
+    :field obc_acc_mpu_y: ax25_frame.payload.ax25_info.body.bytes.obc_acc_mpu_y
+    :field obc_acc_mpu_z: ax25_frame.payload.ax25_info.body.bytes.obc_acc_mpu_z
+    :field obc_uptime_rst: ax25_frame.payload.ax25_info.body.bytes.obc_uptime_rst
+    :field obc_uptime_total: ax25_frame.payload.ax25_info.body.bytes.obc_uptime_total
+    :field obc_rst_cnt: ax25_frame.payload.ax25_info.body.bytes.obc_rst_cnt
+    :field obc_packet_rec_cnt: ax25_frame.payload.ax25_info.body.bytes.obc_packet_rec_cnt
+    :field obc_suns_temp_yn: ax25_frame.payload.ax25_info.body.bytes.obc_suns_temp_yn
+    :field obc_suns_temp_yp: ax25_frame.payload.ax25_info.body.bytes.obc_suns_temp_yp
+    :field obc_suns_temp_xp: ax25_frame.payload.ax25_info.body.bytes.obc_suns_temp_xp
+    :field obc_suns_temp_xn: ax25_frame.payload.ax25_info.body.bytes.obc_suns_temp_xn
+    :field obc_suns_temp_zn: ax25_frame.payload.ax25_info.body.bytes.obc_suns_temp_zn
+    :field obc_suns_irad_yn: ax25_frame.payload.ax25_info.body.bytes.obc_suns_irad_yn
+    :field obc_suns_irad_yp: ax25_frame.payload.ax25_info.body.bytes.obc_suns_irad_yp
+    :field obc_suns_irad_xp: ax25_frame.payload.ax25_info.body.bytes.obc_suns_irad_xp
+    :field obc_suns_irad_xn: ax25_frame.payload.ax25_info.body.bytes.obc_suns_irad_xn
+    :field obc_suns_irad_zn: ax25_frame.payload.ax25_info.body.bytes.obc_suns_irad_zn
+    :field gps_rst_cnt: ax25_frame.payload.ax25_info.body.bytes.gps_rst_cnt
+    :field gps_fix_quality: ax25_frame.payload.ax25_info.body.bytes.gps_fix_quality
+    :field gps_tracked: ax25_frame.payload.ax25_info.body.bytes.gps_tracked
+    :field gps_temp: ax25_frame.payload.ax25_info.body.bytes.gps_temp
+    :field obc_free_mem: ax25_frame.payload.ax25_info.body.bytes.obc_free_mem
+    :field obc_crc: ax25_frame.payload.ax25_info.body.bytes.obc_crc
     """
     def __init__(self, _io, _parent=None, _root=None):
         self._io = _io
@@ -162,6 +201,56 @@ class Grbalpha(KaitaiStruct):
             return self._m_ssid if hasattr(self, '_m_ssid') else None
 
 
+    class ObcBytes(KaitaiStruct):
+        def __init__(self, _io, _parent=None, _root=None):
+            self._io = _io
+            self._parent = _parent
+            self._root = _root if _root else self
+            self._read()
+
+        def _read(self):
+            self.obc_timestamp = self._io.read_u4le()
+            self.obc_temp = self._io.read_s2le()
+            self.obc_tmp112_xp = self._io.read_s2le()
+            self.obc_tmp112_yp = self._io.read_s2le()
+            self.obc_tmp112_xn = self._io.read_s2le()
+            self.obc_tmp112_yn = self._io.read_s2le()
+            self.obc_tmp112_zp = self._io.read_s2le()
+            self.obc_mag_mmc_x = self._io.read_s2le()
+            self.obc_mag_mmc_y = self._io.read_s2le()
+            self.obc_mag_mmc_z = self._io.read_s2le()
+            self.obc_mag_mpu_x = self._io.read_s2le()
+            self.obc_mag_mpu_y = self._io.read_s2le()
+            self.obc_mag_mpu_z = self._io.read_s2le()
+            self.obc_mpu_temp = self._io.read_f4le()
+            self.obc_gyr_mpu_x = self._io.read_s2le()
+            self.obc_gyr_mpu_y = self._io.read_s2le()
+            self.obc_gyr_mpu_z = self._io.read_s2le()
+            self.obc_acc_mpu_x = self._io.read_s2le()
+            self.obc_acc_mpu_y = self._io.read_s2le()
+            self.obc_acc_mpu_z = self._io.read_s2le()
+            self.obc_uptime_rst = self._io.read_u4le()
+            self.obc_uptime_total = self._io.read_u4le()
+            self.obc_rst_cnt = self._io.read_u4le()
+            self.obc_packet_rec_cnt = self._io.read_u4le()
+            self.obc_suns_temp_yn = self._io.read_u2le()
+            self.obc_suns_temp_yp = self._io.read_u2le()
+            self.obc_suns_temp_xp = self._io.read_u2le()
+            self.obc_suns_temp_xn = self._io.read_u2le()
+            self.obc_suns_temp_zn = self._io.read_u2le()
+            self.obc_suns_irad_yn = self._io.read_u2le()
+            self.obc_suns_irad_yp = self._io.read_u2le()
+            self.obc_suns_irad_xp = self._io.read_u2le()
+            self.obc_suns_irad_xn = self._io.read_u2le()
+            self.obc_suns_irad_zn = self._io.read_u2le()
+            self.gps_rst_cnt = self._io.read_u4le()
+            self.gps_fix_quality = self._io.read_u1()
+            self.gps_tracked = self._io.read_u1()
+            self.gps_temp = self._io.read_s2le()
+            self.obc_free_mem = self._io.read_u2le()
+            self.obc_crc = self._io.read_u2le()
+
+
     class Repeaters(KaitaiStruct):
         def __init__(self, _io, _parent=None, _root=None):
             self._io = _io
@@ -204,6 +293,7 @@ class Grbalpha(KaitaiStruct):
             self._read()
 
         def _read(self):
+            self.skip_first_comma = self._io.read_u1()
             self.pkt_type = (self._io.read_bytes_term(44, False, True, True)).decode(u"utf8")
             self.pass_uptime = (self._io.read_bytes_term(44, False, True, True)).decode(u"utf8")
             self.uptime_total_raw = (self._io.read_bytes_term(44, False, True, True)).decode(u"utf8")
@@ -490,7 +580,11 @@ class Grbalpha(KaitaiStruct):
             self._read()
 
         def _read(self):
-            self.string = (self._io.read_bytes_full()).decode(u"utf8")
+            self._raw__raw_bytes = self._io.read_bytes(124)
+            _process = satnogsdecoders.process.B64decode()
+            self._raw_bytes = _process.decode(self._raw__raw_bytes)
+            _io__raw_bytes = KaitaiStream(BytesIO(self._raw_bytes))
+            self.bytes = Grbalpha.ObcBytes(_io__raw_bytes, self, self._root)
 
 
     class CallsignRaw(KaitaiStruct):
@@ -515,12 +609,22 @@ class Grbalpha(KaitaiStruct):
             self._read()
 
         def _read(self):
-            self.packet_type = self._io.read_u1()
-            _on = self.packet_type
+            _on = self.packet_type_q
             if _on == 44:
                 self.body = Grbalpha.Comd(self._io, self, self._root)
             else:
                 self.body = Grbalpha.Obc(self._io, self, self._root)
 
+        @property
+        def packet_type_q(self):
+            if hasattr(self, '_m_packet_type_q'):
+                return self._m_packet_type_q if hasattr(self, '_m_packet_type_q') else None
+
+            _pos = self._io.pos()
+            self._io.seek(0)
+            self._m_packet_type_q = self._io.read_u1()
+            self._io.seek(_pos)
+            return self._m_packet_type_q if hasattr(self, '_m_packet_type_q') else None
+
 
 
